@@ -76,6 +76,11 @@ MODULE_DIRECTORY = {
     0x36: 'VMBEL4',
     0x37: 'VMBELO',
     0x39: 'VMBSIG',
+    0x3A: 'VMBGP1-2',
+    0x3B: 'VMBGP2-2',
+    0x3C: 'VMBGP4-2',
+    0x3D: 'VMBGPOD-2',
+    0x3E: 'VMBGP4PIR-2'
 }
 
 #pylint: disable-msg=C0413
