@@ -6,10 +6,10 @@ from velbus.messages.bus_active import BusActiveMessage
 from velbus.messages.bus_error_counter_status_request import BusErrorStatusRequestMessage
 from velbus.messages.bus_error_counter_status import BusErrorCounterStatusMessage
 from velbus.messages.bus_off import BusOffMessage
-from velbus.messages.channel_name_part1 import ChannelNamePart1Message, ChannelNamePart1Message2
-from velbus.messages.channel_name_part2 import ChannelNamePart2Message, ChannelNamePart2Message2
-from velbus.messages.channel_name_part3 import ChannelNamePart3Message, ChannelNamePart3Message2
-from velbus.messages.channel_name_request import ChannelNameRequestMessage
+from velbus.messages.channel_name_part1 import ChannelNamePart1Message, ChannelNamePart1Message2, ChannelNamePart1Message3
+from velbus.messages.channel_name_part2 import ChannelNamePart2Message, ChannelNamePart2Message2, ChannelNamePart2Message3
+from velbus.messages.channel_name_part3 import ChannelNamePart3Message, ChannelNamePart3Message2, ChannelNamePart3Message3
+from velbus.messages.channel_name_request import ChannelNameRequestMessage, ChannelNameRequestMessage2
 from velbus.messages.clear_led import ClearLedMessage
 from velbus.messages.fast_blinking_led import FastBlinkingLedMessage
 from velbus.messages.interface_status_request import InterfaceStatusRequestMessage
@@ -45,11 +45,17 @@ from velbus.messages.very_fast_blinking_led import VeryFastBlinkingLedMessage
 from velbus.messages.write_data_to_memory import WriteDataToMemoryMessage
 from velbus.messages.write_memory_block import WriteMemoryBlockMessage
 from velbus.messages.write_module_address_and_serial_number import WriteModuleAddressAndSerialNumberMessage
-from velbus.messages.cover_down import CoverDownMessage
-from velbus.messages.cover_up import CoverUpMessage
-from velbus.messages.blind_status import BlindStatusMessage
+from velbus.messages.cover_down import CoverDownMessage, CoverDownMessage2
+from velbus.messages.cover_up import CoverUpMessage, CoverUpMessage2
+from velbus.messages.cover_off import CoverOffMessage, CoverOffMessage2 
+from velbus.messages.blind_status import BlindStatusMessage, BlindStatusNgMessage
 from velbus.messages.sensor_temperature import SensorTemperatureMessage
 from velbus.messages.kwh_status import KwhStatusMessage
 from velbus.messages.counter_status import CounterStatusMessage
 from velbus.messages.counter_status_request import CounterStatusRequestMessage
 from velbus.messages.module_subtype import ModuleSubTypeMessage
+from velbus.messages.set_temperature import SetTemperatureMessage
+from velbus.messages.meteo_raw import MeteoRawMessage
+from velbus.messages.set_realtime_clock import SetRealtimeClock
+from velbus.messages.set_date import SetDate
+from velbus.messages.set_daylight_saving import SetDaylightSaving
