@@ -2,6 +2,7 @@
 :author: Thomas Delaet <thomas@delaet.org>
 """
 import velbus
+import json
 
 COMMAND_CODE = 0xf1
 
@@ -41,18 +42,20 @@ class ChannelNamePart2Message(velbus.Message):
             self.channels_to_byte([self.channel])
             ]) + bytes(self.name, 'utf-8')
 
-class ChannelNamePart2Message2(velbus.Message):
+    def to_json(self):
+        """
+        :return: str
+        """
+        json_dict = self.to_json_basic()
+        json_dict['channel'] = self.channel
+        return json.dumps(json_dict)
+
+
+class ChannelNamePart2Message2(ChannelNamePart2Message):
     """
     send by: VMBGP*
     received by:
     """
-
-    def __init__(self, address=None):
-        velbus.Message.__init__(self)
-        self.channel = 0
-        self.name = ""
-        self.set_defaults(address)
-
     def populate(self, priority, address, rtr, data):
         """
         :return: None
@@ -65,14 +68,23 @@ class ChannelNamePart2Message2(velbus.Message):
         self.channel = data[0]
         self.name = "".join([chr(x) for x in data[1:]])
 
-    def data_to_binary(self):
+
+class ChannelNamePart2Message3(ChannelNamePart2Message):
+    """
+    send by: VMBGP*
+    received by:
+    """
+    def populate(self, priority, address, rtr, data):
         """
-        :return: bytes
+        :return: None
         """
-        return bytes([
-            COMMAND_CODE,
-            self.channel,
-            ]) + bytes(self.name, 'utf-8')
+        assert isinstance(data, bytes)
+        self.needs_low_priority(priority)
+        self.needs_no_rtr(rtr)
+        self.needs_data(data, 5)
+        self.set_attributes(priority, address, rtr)
+        self.channel = (data[0] >> 1) & 0x03
+        self.name = "".join([chr(x) for x in data[1:]])
 
 
 velbus.register_command(COMMAND_CODE, ChannelNamePart2Message)
@@ -81,3 +93,6 @@ velbus.register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP2')
 velbus.register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP4')
 velbus.register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP0')
 velbus.register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGPOD')
+velbus.register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP4PIR')
+velbus.register_command(COMMAND_CODE, ChannelNamePart2Message3, 'VMB1BL')
+velbus.register_command(COMMAND_CODE, ChannelNamePart2Message3, 'VMB2BL')
