@@ -24,15 +24,11 @@ class SwitchRelayOffMessage(velbus.Message):
         :return: None
         """
         assert isinstance(data, bytes)
-        self.logger.debug("Populating message: priority %s, address: %s, channels: %s", str(
-            priority), str(address), str(data))
         self.needs_high_priority(priority)
         self.needs_no_rtr(rtr)
         self.needs_data(data, 1)
         self.set_attributes(priority, address, rtr)
-        self.logger.debug("Setting relay channels to %s",
-                          str(self.byte_to_channels(data)))
-        self.relay_channels = self.byte_to_channels(data)
+        self.relay_channels = self.byte_to_channels(data[0])
 
     def to_json(self):
         """
