@@ -79,6 +79,11 @@ class Module(object):
         else:
             self._on_message(message)
 
+    def _call_callback(self, channel):
+        if channel in self._callbacks:
+            for callback in self._callbacks[channel]:
+                callback(self._is_closed[channel])
+
     def _on_message(self, message):
         pass
 
@@ -92,9 +97,10 @@ class Module(object):
                 pass
             callback = callb
         if len(self._loaded_callbacks) == 0:
-            message = velbus.ChannelNameRequestMessage(self._address)
-            message.channels = list(range(1, self.number_of_channels() + 1))
-            self._controller.send(message)
+            self._request_module_status()
+            self._request_channel_name()
+        else:
+            print("++++++++++++++++++++++++++++++++++")
         self._loaded_callbacks.append(callback)
         self._load()
 
@@ -147,6 +153,16 @@ class Module(object):
                 for name_index in range(1, 4):
                     if not isinstance(self._name_data[channel][name_index], str):
                         return False
-            except Exception:
+            except Exception as exp:
                 return False
         return True
+
+    def _request_module_status(self):
+        message = velbus.ModuleStatusRequestMessage(self._address)
+        message.channels = list(range(1, self.number_of_channels()+1))
+        self._controller.send(message)
+
+    def _request_channel_name(self):
+        message = velbus.ChannelNameRequestMessage(self._address)
+        message.channels = list(range(1, self.number_of_channels() + 1))
+        self._controller.send(message)
