@@ -35,15 +35,10 @@ class VMBGPxModule(velbus.Module):
     def getCurTemp(self):
         return self._cur
 
-    def _load(self):
-        message = velbus.ModuleStatusRequestMessage(self._address)
-        message.channels = list(range(1, self.number_of_channels()+1))
-        self._controller.send(message)
-
     def number_of_channels(self):
-        # 1-32 = inputs
-        # 33 = temp sensor
-        return 33
+        # 1-8 = inputs
+        # 9 = temp sensor
+        return 9
 
     def _on_message(self, message):
         if isinstance(message, velbus.SensorTemperatureMessage):
@@ -85,7 +80,7 @@ class VMBGPxModule(velbus.Module):
         self._callbacks[channel].append(callback)
 
     def get_categories(self, channel):
-        if channel == 33:
+        if channel == 9:
             return ['sensor']
         elif channel in self._is_enabled and self._is_enabled[channel]:
             return ['binary_sensor']
@@ -113,8 +108,81 @@ class VMBGPxModule(velbus.Module):
         """
         return '°C'
 
+
+class VMBGPxDModule(VMBGPxModule):
+    
+    def __init__(self, module_type, module_name, module_address, controller):
+        VMBGPxModule.__init__(self, module_type, module_name, module_address, controller)
+        self._cmode = None
+        self._target = None
+
+    def _on_message(self, message):
+        if isinstance(message, velbus.TempSensorStatusMessage):
+            self._cur = message.current_temp
+            self._target = message.target_temp
+            self._cmode = message.mode_str
+            self._cstatus = message.status_str
+            if 33 in self._callbacks:
+                for callback in self._callbacks[33]:
+                    callback(message.getCurTemp())
+        VMBGPxModule._on_message(self, message)
+
+    def get_categories(self, channel):
+        if channel == 33:
+            return ['sensor', 'climate']
+        elif channel in self._is_enabled and self._is_enabled[channel]:
+            return ['binary_sensor']
+        else:
+            return []
+
+    def get_climate_mode(self):
+        return self._cmode
+
+    def get_climate_target(self):
+        return self._target
+
+    def set_mode(self, mode):
+        if mode == "safe":
+            message = velbus.SwitchToSafeMessage(self._address)
+        elif mode == "night":
+            message = velbus.SwitchToNightMessage(self._address)
+        elif mode == "day":
+            message = velbus.SwitchToDayMessage(self._address)
+        elif mode == "comfort":
+            message = velbus.SwitchToComfortMessage(self._address)
+        self._controller.send(message)
+
+    def set_temp(self, temp):
+        message = velbus.SetTemperatureMessage(self._address)
+        message.temp = temp * 2
+        self._controller.send(message)
+
+    def number_of_channels(self):
+        return 33
+
+
+class VMBGPPirModule(velbus.Module):
+    def number_of_channels(self):
+        # 1-4 = buttons
+        # 5 = dark/light
+        # 6 = Motion
+        # 7 = light dependant motion
+        # 8 = absece
+        # 9 = temperature
+        return 9
+
+    def get_categories(self, channel):
+        if channel == 9:
+            return ['sensor']
+        elif channel in self._is_enabled and self._is_enabled[channel]:
+            return ['binary_sensor']
+        else:
+            return []
+
+
 velbus.register_module('VMBGP1', VMBGPxModule)
 velbus.register_module('VMBGP2', VMBGPxModule)
 velbus.register_module('VMBGP4', VMBGPxModule)
-velbus.register_module('VMBGP0', VMBGPxModule)
-velbus.register_module('VMBGPOD', VMBGPxModule)
+velbus.register_module('VMBGP0', VMBGPxDModule)
+velbus.register_module('VMBGPOD', VMBGPxDModule)
+velbus.register_module('VMBGP4PIR', VMBGPPirModule)
