@@ -24,11 +24,6 @@ class VMBIROModule(velbus.Module):
     def getCurTemp(self):
         return self._cur
 
-    def _load(self):
-        message = velbus.ModuleStatusRequestMessage(self._address)
-        message.channels = list(range(1, self.number_of_channels()+1))
-        self._controller.send(message)
-
     def _on_message(self, message):
         if isinstance(message, velbus.SensorTemperatureMessage):
             self._cur = message.cur 
@@ -47,7 +42,25 @@ class VMBIROModule(velbus.Module):
         self._callbacks.append(callback)
 
     def get_categories(self, channel):
-        return ['temp_sensor']
+        return ['sensor']
+
+    def get_state(self, channel):
+        """
+        Ignore channel
+        """
+        return self._cur
+
+    def get_class(self, channel):
+        """
+        Ignore channel
+        """
+        return 'temperature'
+
+    def get_unit(self, channel):
+        """
+        Ignore channel
+        """
+        return '°C'
 
 
 velbus.register_module('VMBIRO', VMBIROModule)
